@@ -3,7 +3,8 @@ require XSLoader;
 my $orig_load = \&XSLoader::load;
 no warnings "redefine";
 *XSLoader::load = sub {
-	die "XS loading disabled for Math::Decimal" if $_[0] eq "Math::Decimal";
+	die "XS loading disabled for Math::Decimal"
+		if ($_[0] || "") eq "Math::Decimal";
 	goto &$orig_load;
 };
 
